@@ -15,6 +15,7 @@ from typing import Dict, Tuple
 
 import uvicorn  # type: ignore
 from fastapi import FastAPI
+from starlette.responses import FileResponse
 
 from soco_cli.__init__ import __version__ as version  # type: ignore
 from soco_cli.api import get_all_speaker_names
@@ -32,8 +33,19 @@ PREFIX_MACRO = PREFIX + "Macro: "
 MACROS: Dict[str, str] = {}
 MACRO_FILE = ""
 PP = pprint.PrettyPrinter(indent=len(PREFIX_MACRO))
+FAVICON_PATH = "favicon.ico"
 
-sc_app = FastAPI()
+
+sc_app = FastAPI(
+    title="SoCo-CLI HTTP API Server",
+    description="**Use this interface to review and test SoCo-CLI's HTTP API**",
+    version=version,
+    contact={"name": "Avantrec Ltd", "url": "https://github.com/avantrec/soco-cli"},
+    license_info={
+        "name": "Apache 2.0",
+        "url": "https://www.apache.org/licenses/LICENSE-2.0.html",
+    },
+)
 
 
 def command_core(
@@ -93,6 +105,11 @@ def root() -> Dict:
     return {"info": INFO}
 
 
+@sc_app.get("/favicon.ico", include_in_schema=False)
+def favicon() -> FileResponse:
+    return FileResponse(abspath(FAVICON_PATH))
+
+
 @sc_app.get("/rediscover")
 def rediscover() -> Dict:
     rescan_speakers(timeout=2.0)
@@ -108,7 +125,8 @@ def speakers() -> Dict:
     return {"speakers": speakers}
 
 
-@sc_app.get("/macros")
+# Deprecated
+@sc_app.get("/macros", include_in_schema=False)
 def macros() -> Dict:
     return MACROS
 
@@ -165,6 +183,82 @@ def run_macro_5(
     return {"command": command, "result": result}
 
 
+@sc_app.get("/macro/{macro_name}/{arg_1}/{arg_2}/{arg_3}/{arg_4}/{arg_5}/{arg_6}")
+def run_macro_6(
+    macro_name: str,
+    arg_1: str,
+    arg_2: str,
+    arg_3: str,
+    arg_4: str,
+    arg_5: str,
+    arg_6: str,
+) -> Dict:
+    command, result = _process_macro(
+        macro_name, arg_1, arg_2, arg_3, arg_4, arg_5, arg_6
+    )
+    return {"command": command, "result": result}
+
+
+@sc_app.get(
+    "/macro/{macro_name}/{arg_1}/{arg_2}/{arg_3}/{arg_4}/{arg_5}/{arg_6}/{arg_7}"
+)
+def run_macro_7(
+    macro_name: str,
+    arg_1: str,
+    arg_2: str,
+    arg_3: str,
+    arg_4: str,
+    arg_5: str,
+    arg_6: str,
+    arg_7: str,
+) -> Dict:
+    command, result = _process_macro(
+        macro_name, arg_1, arg_2, arg_3, arg_4, arg_5, arg_6, arg_7
+    )
+    return {"command": command, "result": result}
+
+
+@sc_app.get(
+    "/macro/{macro_name}/{arg_1}/{arg_2}/{arg_3}/{arg_4}/{arg_5}/{arg_6}/{arg_7}/{arg_8}"
+)
+def run_macro_8(
+    macro_name: str,
+    arg_1: str,
+    arg_2: str,
+    arg_3: str,
+    arg_4: str,
+    arg_5: str,
+    arg_6: str,
+    arg_7: str,
+    arg_8: str,
+) -> Dict:
+    command, result = _process_macro(
+        macro_name, arg_1, arg_2, arg_3, arg_4, arg_5, arg_6, arg_7, arg_8
+    )
+    return {"command": command, "result": result}
+
+
+@sc_app.get(
+    "/macro/{macro_name}/{arg_1}/{arg_2}/{arg_3}/{arg_4}/{arg_5}/{arg_6}/{arg_7}/{arg_8}/{arg_9}"
+)
+def run_macro_9(
+    macro_name: str,
+    arg_1: str,
+    arg_2: str,
+    arg_3: str,
+    arg_4: str,
+    arg_5: str,
+    arg_6: str,
+    arg_7: str,
+    arg_8: str,
+    arg_9: str,
+) -> Dict:
+    command, result = _process_macro(
+        macro_name, arg_1, arg_2, arg_3, arg_4, arg_5, arg_6, arg_7, arg_8, arg_9
+    )
+    return {"command": command, "result": result}
+
+
 @sc_app.get("/{speaker}/{action}")
 def action_0(speaker: str, action: str) -> Dict:
     return command_core(speaker, action, use_local=USE_LOCAL)
@@ -293,7 +387,7 @@ def _lookup_macro(macro_name: str) -> str:
 
 def _substitute_variables(macro: str, args: Tuple) -> str:
     """Substitute positional parameters with supplied variables."""
-    parameters_list = ["%1", "%2", "%3", "%4", "%5"]
+    parameters_list = ["%1", "%2", "%3", "%4", "%5", "%6", "%7", "%8", "%9"]
     supplied_parameters = set(parameters_list[: len(args)])
     parameters = set(parameters_list)
     used_parameters = []
